@@ -63,12 +63,12 @@ import java.util.Queue;
 import java.util.concurrent.ConcurrentLinkedQueue;
 import javax.activation.DataHandler;
 import javax.mail.Address;
+import javax.mail.Message.RecipientType;
 import javax.mail.MessagingException;
 import javax.mail.Multipart;
 import javax.mail.NoSuchProviderException;
 import javax.mail.Part;
 import javax.mail.Transport;
-import javax.mail.Message.RecipientType;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MailDateFormat;
 import javax.mail.internet.MimeBodyPart;
@@ -133,7 +133,7 @@ public final class SMTPTransport extends MailTransport {
 
     private final UserSettingMail usm;
 
-    private volatile SMTPConfig smtpConfig;
+    private volatile SMTPConfig cachedSmtpConfig;
 
     protected SMTPTransport() {
         super();
@@ -254,8 +254,8 @@ public final class SMTPTransport extends MailTransport {
                         /*
                          * Specify SSL protocols
                          */
-                        smtpProps.put("mail.smtp.ssl.protocols", "SSLv3 TLSv1");
-                        smtpProps.put("mail.smtp.ssl", "true");
+                        // smtpProps.put("mail.smtp.ssl.protocols", "SSLv3 TLSv1");
+                        // smtpProps.put("mail.smtp.ssl", "true");
                         /*
                          * Needed for JavaMail >= 1.4
                          */
@@ -278,7 +278,7 @@ public final class SMTPTransport extends MailTransport {
                          * Specify SSL protocols
                          */
                         smtpProps.put("mail.smtp.ssl.protocols", "SSLv3 TLSv1");
-                        smtpProps.put("mail.smtp.ssl", "true");
+                        // smtpProps.put("mail.smtp.ssl", "true");
                         /*
                          * Needed for JavaMail >= 1.4
                          */
@@ -302,15 +302,15 @@ public final class SMTPTransport extends MailTransport {
     }
 
     private SMTPConfig getTransportConfig0() throws MailException {
-        if (smtpConfig == null) {
+        if (cachedSmtpConfig == null) {
             synchronized (this) {
-                if (smtpConfig == null) {
-                    smtpConfig = TransportConfig.getTransportConfig(SMTPConfig.class, new SMTPConfig(), session, accountId);
-                    smtpConfig.setTransportProperties(createNewMailProperties());
+                if (cachedSmtpConfig == null) {
+                    cachedSmtpConfig = TransportConfig.getTransportConfig(SMTPConfig.class, new SMTPConfig(), session, accountId);
+                    cachedSmtpConfig.setTransportProperties(createNewMailProperties());
                 }
             }
         }
-        return smtpConfig;
+        return cachedSmtpConfig;
     }
 
     private static final String ACK_TEXT =
@@ -358,6 +358,7 @@ public final class SMTPTransport extends MailTransport {
              * Set header
              */
             smtpMessage.setHeader(MessageHeaders.HDR_X_PRIORITY, "3 (normal)");
+            smtpMessage.setHeader(MessageHeaders.HDR_IMPORTANCE, "Medium");
             /*
              * Subject
              */
@@ -427,14 +428,18 @@ public final class SMTPTransport extends MailTransport {
              */
             final long start = System.currentTimeMillis();
             final Transport transport = getSMTPSession().getTransport(SMTPProvider.PROTOCOL_SMTP.getName());
-            if (smtpConfig.getSMTPProperties().isSmtpAuth()) {
-                transport.connect(
-                    smtpConfig.getServer(),
-                    smtpConfig.getPort(),
-                    smtpConfig.getLogin(),
-                    encodePassword(smtpConfig.getPassword()));
-            } else {
-                transport.connect();
+            try {
+                if (smtpConfig.getSMTPProperties().isSmtpAuth()) {
+                    transport.connect(
+                        smtpConfig.getServer(),
+                        smtpConfig.getPort(),
+                        smtpConfig.getLogin(),
+                        encodePassword(smtpConfig.getPassword()));
+                } else {
+                    transport.connect();
+                }
+            } catch (final javax.mail.AuthenticationFailedException e) {
+                throw new MIMEMailException(MIMEMailException.Code.TRANSPORT_INVALID_CREDENTIALS, e, smtpConfig.getServer(), e.getMessage());
             }
             try {
                 saveChangesSafe(smtpMessage);
@@ -463,11 +468,20 @@ public final class SMTPTransport extends MailTransport {
             try {
                 final long start = System.currentTimeMillis();
                 final Transport transport = getSMTPSession().getTransport(SMTPProvider.PROTOCOL_SMTP.getName());
-                if (getTransportConfig0().getSMTPProperties().isSmtpAuth()) {
-                    final SMTPConfig config = getTransportConfig0();
-                    transport.connect(config.getServer(), config.getPort(), config.getLogin(), encodePassword(config.getPassword()));
-                } else {
-                    transport.connect();
+                final SMTPConfig smtpConfig = getTransportConfig0();
+                try {
+                    if (smtpConfig.getSMTPProperties().isSmtpAuth()) {
+                        final String encPass = encodePassword(smtpConfig.getPassword());
+                        transport.connect(smtpConfig.getServer(), smtpConfig.getPort(), smtpConfig.getLogin(), encPass);
+                    } else {
+                        transport.connect();
+                    }
+                } catch (final javax.mail.AuthenticationFailedException e) {
+                    throw new MIMEMailException(
+                        MIMEMailException.Code.TRANSPORT_INVALID_CREDENTIALS,
+                        e,
+                        smtpConfig.getServer(),
+                        e.getMessage());
                 }
                 try {
                     saveChangesSafe(smtpMessage);
@@ -522,14 +536,21 @@ public final class SMTPTransport extends MailTransport {
                     LOG.debug(new StringBuilder(128).append("SMTP mail prepared for transport in ").append(
                         System.currentTimeMillis() - startPrep).append("msec").toString());
                 }
-
                 final long start = System.currentTimeMillis();
                 final Transport transport = getSMTPSession().getTransport(SMTPProvider.PROTOCOL_SMTP.getName());
-                if (smtpConfig.getSMTPProperties().isSmtpAuth()) {
-                    final String encPass = encodePassword(smtpConfig.getPassword());
-                    transport.connect(smtpConfig.getServer(), smtpConfig.getPort(), smtpConfig.getLogin(), encPass);
-                } else {
-                    transport.connect();
+                try {
+                    if (smtpConfig.getSMTPProperties().isSmtpAuth()) {
+                        final String encPass = encodePassword(smtpConfig.getPassword());
+                        transport.connect(smtpConfig.getServer(), smtpConfig.getPort(), smtpConfig.getLogin(), encPass);
+                    } else {
+                        transport.connect();
+                    }
+                } catch (final javax.mail.AuthenticationFailedException e) {
+                    throw new MIMEMailException(
+                        MIMEMailException.Code.TRANSPORT_INVALID_CREDENTIALS,
+                        e,
+                        smtpConfig.getServer(),
+                        e.getMessage());
                 }
                 try {
                     saveChangesSafe(smtpMessage);
@@ -604,13 +625,16 @@ public final class SMTPTransport extends MailTransport {
         boolean close = false;
         try {
             final SMTPConfig config = getTransportConfig0();
-            if (config.getSMTPProperties().isSmtpAuth()) {
-                final String encPass = encodePassword(config.getPassword());
-                transport.connect(config.getServer(), config.getPort(), config.getLogin(), encPass);
-                close = true;
-            } else {
-                transport.connect();
+            try {
+                if (config.getSMTPProperties().isSmtpAuth()) {
+                    final String encPass = encodePassword(config.getPassword());
+                    transport.connect(config.getServer(), config.getPort(), config.getLogin(), encPass);
+                } else {
+                    transport.connect();
+                }
                 close = true;
+            } catch (final javax.mail.AuthenticationFailedException e) {
+                throw new MIMEMailException(MIMEMailException.Code.TRANSPORT_INVALID_CREDENTIALS, e, config.getServer(), e.getMessage());
             }
         } catch (final MessagingException e) {
             throw MIMEMailException.handleMessagingException(e);
